<?php
/**
 * Color Setting
 * @package Serifi
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

function serifi_customize_register_colour( $wp_customize ) {

// Colour Options Panel
  $wp_customize->add_panel( 'colors', array(
    'priority' => 40,
    'title'    => esc_html__( 'Colours', 'serifi' ),
  ) ); 
	
  // SECTION - PRESET COLOURS 
  $wp_customize->add_section( 'serifi_preset_colours', array(
      'title' => esc_html__( 'Preset Colours', 'serifi' ),
	  'priority' => 10,
      'panel' => 'colors'
    ) );	
	
  // SECTION - CONTENT COLOURS 
  $wp_customize->add_section( 'serifi_content_colours', array(
      'title' => esc_html__( 'Content Colors', 'serifi' ),
	  'priority' => 15,
      'panel' => 'colors'
    ) );
	
/* PRESET SETTINGS
==================================================== */	
   // Presets
    $wp_customize->add_setting( 'serifi_presets', array(
		'default' => 'preset1',
		'sanitize_callback' => 'serifi_sanitize_select',
    )
  );
  
  $wp_customize->add_control( new Serifi_Radio_Image_Control(	
	$wp_customize,	'serifi_presets', array(
		'label' => esc_html__( 'Preset Groups', 'serifi' ),
		 'description' => esc_html__( 'Choose a preset colour palette for your theme. This will load a variety of accent colours for select elements in your page.', 'serifi' ),
		'section' => 'serifi_preset_colours',
		'type' => 'radio-image',
		'choices' => serifi_colour_preset_options()),
	)
  );	
	

    /** Enable Custom Accent Colours */
    $wp_customize->add_setting( 'serifi_custom_accent_colours', array(
            'default'           => false,
            'sanitize_callback' => 'serifi_sanitize_checkbox',
        ) 
    );
    
    $wp_customize->add_control( new Serifi_Toggle_Control( $wp_customize, 'serifi_custom_accent_colours',	array(
				'section'     => 'serifi_preset_colours',
				'label'	      => esc_html__( 'Custom Accent Colours', 'serifi' ),
                'description' => esc_html__( 'Enable to change the theme accent colours to be your own.', 'serifi' ),
			)
		)
	);	


	// Custom Primary Colour
    $wp_customize->add_setting( 'serifi_custom_primary_colour', array(
            'default'           => '#818f9e',
			'transport' => 'postMessage',
            'sanitize_callback' => 'serifi_sanitize_hex_colour'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'serifi_custom_primary_colour', array(
                'label'       => esc_html__( 'Primary Colour', 'serifi' ),
                'description' => esc_html__( 'Sets a custom primary accent colour for your theme.', 'serifi' ),
                'section'     => 'serifi_preset_colours',  
				'active_callback' => 'serifi_custom_accent_colours_show',				
     ) ) ); 	

	// Custom Secondary Colour
    $wp_customize->add_setting( 'serifi_custom_secondary_colour', array(
            'default'           => '#a6924a',
			'transport' => 'postMessage',
            'sanitize_callback' => 'serifi_sanitize_hex_colour'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'serifi_custom_secondary_colour', array(
                'label'       => esc_html__( 'Secondary Colour', 'serifi' ),
                'description' => esc_html__( 'Sets a custom secondary accent colour for your theme.', 'serifi' ),
                'section'     => 'serifi_preset_colours',       
				'active_callback' => 'serifi_custom_accent_colours_show',				
     ) ) ); 	

	// Custom Tertiary Colour
    $wp_customize->add_setting( 'serifi_custom_tertiary_colour', array(
            'default'           => '#2d283f',
			'transport' => 'postMessage',
            'sanitize_callback' => 'serifi_sanitize_hex_colour'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'serifi_custom_tertiary_colour', array(
                'label'       => esc_html__( 'Tertiary Colour', 'serifi' ),
                'description' => esc_html__( 'Sets a custom tertiary (third) accent colour for your theme.', 'serifi' ),
                'section'     => 'serifi_preset_colours',    
				'active_callback' => 'serifi_custom_accent_colours_show',				
     ) ) ); 	
	 
/* CONTENT COLOUR SETTINGS
==================================================== */	
    $wp_customize->add_setting( 'serifi_content_bg_colour', array(
            'default'           => '#fff',
			'transport' => 'postMessage',
            'sanitize_callback' => 'serifi_sanitize_hex_colour'
     ) );

    $wp_customize->add_control( new WP_Customize_Color_Control( 
		$wp_customize, 'serifi_content_bg_colour', array(
                'label'       => esc_html__( 'Content Background', 'serifi' ),
                'description' => esc_html__( 'When not using preset colours, this sets the colour for your content area background.', 'serifi' ),
                'section'     => 'serifi_content_colours',             
     ) ) ); 	
	
}
add_action( 'customize_register', 'serifi_customize_register_colour' );


/* CALLBACKS
==================================================== */	
// Show custom accent colour selectors callback
function serifi_custom_accent_colours_show( $control ) {
   if ( $control->manager->get_setting('serifi_custom_accent_colours')->value() == 'true' ) {
      return true;
   } else {
      return false;
   }
}
