<?php
/**
 * Blog Post Settings
 * @package Serifi
 * @since 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if( ! function_exists( 'serifi_customize_register_post' ) ) :
function serifi_customize_register_post( $wp_customize ) {
    
	// Heading - Post show hide
	$wp_customize->add_control( new Serifi_Note_Control(
		$wp_customize, 'serifi_post_showhide_note', array(
			'label' => esc_html__( 'Show or Hide Settings', 'serifi' ),
			'section' => 'serifi_post_options',
			'priority' => 3,
			'settings' => array(),
	) ) );	
	
    /** Post Options */
    $wp_customize->add_section( 'serifi_post_options', array(
            'title'    => esc_html__( 'Post Options', 'serifi' ),
            'priority' => 23,
        )
    );
	
    // Hide the post footer
    $wp_customize->add_setting( 'serifi_hide_post_footer', array(
		'default'           => 0,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'serifi_sanitize_checkbox'
	) );
    
    $wp_customize->add_control( new Serifi_Toggle_Control( 
		$wp_customize, 'serifi_hide_post_footer', array(
		'section'     => 'serifi_post_options',
		'priority' => 8,
		'label'	      => esc_html__( 'Hide the Post Footer', 'serifi' ),
		'description' => esc_html__( 'Show or hide the post footer where the tags and categories are shown.', 'serifi' ),
	) ) );	
	
    // Hide Author Bio
    $wp_customize->add_setting( 'serifi_hide_author_bio', array(
		'default'           => 0,
		'transport'         => 'postMessage',
		'sanitize_callback' => 'serifi_sanitize_checkbox'
	) );
    
    $wp_customize->add_control( new Serifi_Toggle_Control( 
		$wp_customize, 'serifi_hide_author_bio', array(
		'section'     => 'serifi_post_options',
		'priority' => 9,
		'label'	      => esc_html__( 'Hide Author Bio', 'serifi' ),
		'description' => esc_html__( 'Show or hide the post author biography.', 'serifi' ),
	) ) );
	
}
endif;

add_action( 'customize_register', 'serifi_customize_register_post' );	